/**
 * vue-inertia-composable
 *
 * @description Inertia for Vue2 Composition API.
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.2.2
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */

import { getCurrentInstance } from 'vue';
import ziggy from 'ziggy-js';

function useHeadManager() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$headManager;
  } else {
    warn();
  }
  return void 0;
}
function usePage() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$page;
  } else {
    warn();
  }
  return void 0;
}
function useInertia() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$inertia;
  } else {
    warn();
  }
  return void 0;
}
function useForm(args) {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$inertia.form(args);
  } else {
    warn();
  }
  return void 0;
}
function route(name, params, absolute, config) {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.route(name, params, absolute, config);
  }
  return ziggy(name, params, absolute, config);
}
const warn = () => console.warn(
  `[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`
);
if (window.route === void 0) {
  window.route = route;
}

export { route, useForm, useHeadManager, useInertia, usePage };
